if(!require(gdata)){
  install.packages("gdata", dependencies = T)
}
if(!require(tm)){
  install.packages("tm", dependencies = T)
}
if(!require(ggplot2)){
  install.packages("ggplot2", dependencies = T)
}
if(!require(forcats)){
  install.packages("forcats", dependencies = T)
}
if(!require(xlsx)){
  install.packages("xlsx", dependencies = T)
}


require(gdata)
require(tm)
require(ggplot2)
require(forcats)

library(gridExtra)
library(grid)


library(xlsx)


tableit <- function(t, filename="none"){
  print(sort(t))
  print("total codes")
  print(sum(t))
  write.xlsx(sort(t), file.path("reports/qualitative", paste(filename,".xlsx",sep = "")))
}

chartit <- function(wf, title="none", filename="none"){
  ggplot(data = wf, aes(word, freq)) +
    geom_bar(stat="identity") +
    theme(axis.text.x=element_text(angle=45, hjust=1)) +
    xlab(title)
    ggsave(file.path("reports/qualitative", paste(filename,".png",sep = "")))
}

df <- read.xls(
  file.path("data", "/04_annotated-data-for_R.xlsx"), 
  sheet = 1, 
  header = TRUE
)

# -1 drops the second level of headers
furtherPurposePR.df <- df[,c("v_28c")]
furtherPurposePR.split <- strsplit(as.character(furtherPurposePR.df), ",")
furtherPurposePR.split <- unlist(furtherPurposePR.split[lapply(furtherPurposePR.split,length)>0])


furtherPurposePR.corpus <- Corpus(DataframeSource(as.data.frame(furtherPurposePR.split)))
furtherPurposePR.corpus <- tm_map(furtherPurposePR.corpus, content_transformer(removePunctuation))
furtherPurposePR.corpus <- tm_map(furtherPurposePR.corpus, content_transformer(stripWhitespace))

furtherPurposePR.dtm <- DocumentTermMatrix(furtherPurposePR.corpus)
furtherPurposePR.freq <- sort(colSums(as.matrix(furtherPurposePR.dtm)), decreasing=TRUE)
furtherPurposePR.ord <- order(furtherPurposePR.freq)

furtherPurposePR <- as.table(furtherPurposePR.freq[furtherPurposePR.ord])

tableit(furtherPurposePR, "furtherpurposePR")
wf <- data.frame(word=names(furtherPurposePR.freq), freq=furtherPurposePR.freq)
chartit(wf, "A further purpose of PR is..", "furtherpurposePR")


# -1 drops the second level of headers
faultyPR.df <- df[,c("v_36c")]
faultyPR.split <- strsplit(as.character(faultyPR.df), ",")
faultyPR.split <- unlist(faultyPR.split[lapply(faultyPR.split,length)>0])

faultyPR.corpus <- Corpus(DataframeSource(as.data.frame(faultyPR.split)))
faultyPR.corpus <- tm_map(faultyPR.corpus, content_transformer(removePunctuation))
faultyPR.corpus <- tm_map(faultyPR.corpus, content_transformer(stripWhitespace))

faultyPR.dtm <- DocumentTermMatrix(faultyPR.corpus)
faultyPR.freq <- colSums(as.matrix(faultyPR.dtm))
faultyPR.ord <- order(faultyPR.freq)

tableit(as.table(faultyPR.freq[faultyPR.ord]), "faultyPR")
wf <- data.frame(word=names(faultyPR.freq), freq=faultyPR.freq)
chartit(wf, "Main reasons for unhelpful/grossy faulty reviews..", "faultyPR")


worstExpAuthor.df <- df[,c("v_38c")]
worstExpAuthor.split <- strsplit(as.character(worstExpAuthor.df), ",")
worstExpAuthor.split <- unlist(worstExpAuthor.split[lapply(worstExpAuthor.split,length)>0])
# Removing those with ?
worstExpAuthor.split <- Filter(function(x) !any(grepl("\\?+", x)), worstExpAuthor.split)

worstExpAuthor.corpus <- Corpus(DataframeSource(as.data.frame(worstExpAuthor.split)))
worstExpAuthor.corpus <- tm_map(worstExpAuthor.corpus, content_transformer(stripWhitespace))

worstExpAuthor.dtm <- DocumentTermMatrix(worstExpAuthor.corpus)
worstExpAuthor.freq <- colSums(as.matrix(worstExpAuthor.dtm))
worstExpAuthor.ord <- order(worstExpAuthor.freq)


tableit(as.table(worstExpAuthor.freq[worstExpAuthor.ord]), "worstExpAuthor")
wf <- data.frame(word=names(worstExpAuthor.freq), freq=worstExpAuthor.freq)
chartit(wf,"Worst PR experience as author..","worstExpAuthor")



# -1 drops the second level of headers
worstExpReviewer.df <- df[,c("v_37c")]
worstExpReviewer.split <- strsplit(as.character(worstExpReviewer.df), ",")
worstExpReviewer.split <- unlist(worstExpReviewer.split[lapply(worstExpReviewer.split,length)>0])
# Removing those with ?
worstExpReviewer.split <- Filter(function(x) !any(grepl("\\?+", x)), worstExpReviewer.split)

worstExpReviewer.corpus <- Corpus(DataframeSource(as.data.frame(worstExpReviewer.split)))
worstExpReviewer.corpus <- tm_map(worstExpReviewer.corpus, content_transformer(stripWhitespace))

worstExpReviewer.dtm <- DocumentTermMatrix(worstExpReviewer.corpus)
worstExpReviewer.freq <- colSums(as.matrix(worstExpReviewer.dtm))
worstExpReviewer.ord <- order(worstExpReviewer.freq)

tableit(as.table(worstExpReviewer.freq[worstExpReviewer.ord]), "worstExpReviewer")
wf <- data.frame(word=names(worstExpReviewer.freq), freq=worstExpReviewer.freq)
chartit(wf,"Worst PR experience as reviewer..","worstExpReviewer")




# -1 drops the second level of headers
monetaryCompensation.df <- df[,c("v_56c")]
monetaryCompensation.split <- strsplit(as.character(monetaryCompensation.df), ",")
monetaryCompensation.split <- unlist(monetaryCompensation.split[lapply(monetaryCompensation.split,length)>0])

monetaryCompensation.split <- Filter(function(x) !any(grepl("\\?+", x)), monetaryCompensation.split)

monetaryCompensation.corpus <- Corpus(DataframeSource(as.data.frame(monetaryCompensation.split)))
monetaryCompensation.corpus <- tm_map(monetaryCompensation.corpus, content_transformer(removePunctuation))
monetaryCompensation.corpus <- tm_map(monetaryCompensation.corpus, content_transformer(stripWhitespace))

monetaryCompensation.dtm <- DocumentTermMatrix(monetaryCompensation.corpus)
monetaryCompensation.freq <- sort(colSums(as.matrix(monetaryCompensation.dtm)), decreasing=TRUE)
monetaryCompensation.ord <- order(monetaryCompensation.freq)

tableit(as.table(monetaryCompensation.freq[monetaryCompensation.ord]), "monetaryCompensation")
wf <- data.frame(word=names(monetaryCompensation.freq), freq=monetaryCompensation.freq)
chartit(wf, "Which compensation should reviewers receive?","monetaryCompensation")


# -1 drops the second level of headers
showablePRproof.df <- df[,c("v_59c")]
showablePRproof.split <- strsplit(as.character(showablePRproof.df), ",")
showablePRproof.split <- unlist(showablePRproof.split[lapply(showablePRproof.split,length)>0])

showablePRproof.split <- Filter(function(x) !any(grepl("\\?+", x)), showablePRproof.split)

showablePRproof.corpus <- Corpus(DataframeSource(as.data.frame(showablePRproof.split)))
showablePRproof.corpus <- tm_map(showablePRproof.corpus, content_transformer(removePunctuation))
showablePRproof.corpus <- tm_map(showablePRproof.corpus, content_transformer(stripWhitespace))

showablePRproof.dtm <- DocumentTermMatrix(showablePRproof.corpus)
showablePRproof.freq <- sort(colSums(as.matrix(showablePRproof.dtm)), decreasing=TRUE)
showablePRproof.ord <- order(showablePRproof.freq)

tableit(as.table(showablePRproof.freq[showablePRproof.ord]), "showablePRproof")
wf <- data.frame(word=names(showablePRproof.freq), freq=showablePRproof.freq)
chartit(wf, "Which showable proof should reviewers receive", "showablePRproof")



# -1 drops the second level of headers
whatChangePR.df <- df[,c("v_60c")]
whatChangePR.split <- strsplit(as.character(whatChangePR.df), ",")
whatChangePR.split <- unlist(whatChangePR.split[lapply(whatChangePR.split,length)>0])

whatChangePR.split <- Filter(function(x) !any(grepl("\\?+", x)), whatChangePR.split)

whatChangePR.corpus <- Corpus(DataframeSource(as.data.frame(whatChangePR.split)))
whatChangePR.corpus <- tm_map(whatChangePR.corpus, content_transformer(removePunctuation))
whatChangePR.corpus <- tm_map(whatChangePR.corpus, content_transformer(stripWhitespace))

whatChangePR.dtm <- DocumentTermMatrix(whatChangePR.corpus)
whatChangePR.freq <- sort(colSums(as.matrix(whatChangePR.dtm)), decreasing=TRUE)
whatChangePR.ord <- order(whatChangePR.freq)

tableit(as.table(whatChangePR.freq[whatChangePR.ord]), "whatChangePR")
wf <- data.frame(word=names(whatChangePR.freq), freq=whatChangePR.freq)
chartit(wf, "If you can change one thing in PR...", "whatChangePR")



